@@ -36,9 +36,10 @@ async def ls(root: Root) -> None:
 
     accounts = []
     with root.status("Fetching service accounts") as status:
-        async for account in root.client.service_accounts.list():
-            accounts.append(account)
-            status.update(f"Fetching service accounts ({len(accounts)} loaded)")
+        async with root.client.service_accounts.list() as it:
+            async for account in it:
+                accounts.append(account)
+                status.update(f"Fetching service accounts ({len(accounts)} loaded)")
 
     with root.pager():
         root.print(fmtr(accounts))
@@ -80,7 +81,7 @@ async def create(
         # No pager here as it can make it harder to copy generated token
         root.print(fmtr(account))
         root.print("")
-        root.print(service_account_token_fmtr(token))
+        root.print(service_account_token_fmtr(token), soft_wrap=True)
 
 
 @command()
